check_pars: Check mbd pars

Description Usage Arguments Value Author(s)

View source: R/mbd_checks.R

Description

Check mbd pars

Usage

1
2
3
4
5
6
7
8
check_pars(
  pars,
  safety_checks = TRUE,
  lambda_limit = 10,
  mu_limit = 10,
  nu_limit = 100,
  q_threshold = 0.001
)

Arguments

pars

vector of parameters:

  • pars[1] is lambda, the sympatric speciation rate;

  • pars[2] is mu, the extinction rate;

  • pars[3] is nu, the multiple allopatric speciation trigger rate;

  • pars[4] is q, the single-lineage speciation probability;

safety_checks

TRUE if you want the parameters to be limited to a realistic, but not infinite, parameter space

lambda_limit

Upper limit to lambda estimations.

mu_limit

Upper limit to mu estimations.

nu_limit

Upper limit to nu estimations.

q_threshold

adds a threshold for the evaluation of q. This is due because you never want q to actually be equal to zero or one.

Value

Returns "wrong" if they are wrong, or "right" otherwise.

Author(s)

Giovanni Laudanno


Giappo/mbd documentation built on March 3, 2020, 3:36 a.m.