check_sum_probs: Check the vectors of probability sums computed during...

Description Usage Arguments

View source: R/mbd_loglik_utils.R

Description

Check the vectors of probability sums computed during likelihood integration

Usage

1
check_sum_probs(sum_probs_1, sum_probs_2)

Arguments

sum_probs_1

vector of probability sums, used during the integration of mbd_loglik

sum_probs_2

vector of probability sums, used during the integration of mbd_loglik


Giappo/mbd documentation built on March 3, 2020, 3:36 a.m.