create_a: The A matrix

Description Usage Arguments Details Author(s)

View source: R/mbd_loglik_utils.R

Description

Creates the A matrix, used for likelihood integration between branching times.

Usage

1
2
3
4
5
6
7
create_a(
  pars,
  k,
  lx,
  matrix_builder = mbd::hyper_matrix2,
  no_species_out_of_the_matrix = FALSE
)

Arguments

pars

vector of parameters:

  • pars[1] is lambda, the sympatric speciation rate;

  • pars[2] is mu, the extinction rate;

  • pars[3] is nu, the multiple allopatric speciation trigger rate;

  • pars[4] is q, the single-lineage speciation probability;

k

the number of visible species in the phylogeny at a given time.

lx

it is the number of ODEs considered for the computation.

matrix_builder

function used to build the transition matrix. Default option is hyper_matrix2

no_species_out_of_the_matrix

If true prevents interactions from states describing number of species greater than lx

Details

This is not to be called by the user.

Author(s)

Giovanni Laudanno


Giappo/mbd documentation built on March 3, 2020, 3:36 a.m.