mbd_integrate: performs integration of the ode

Description Usage Arguments Author(s)

Description

performs integration of the ode

Usage

1
mbd_integrate(y, times, func, parms, atol, rtol, tcrit, methode = "lsoda")

Arguments

y

something

times

vector of times

func

a function

parms

some parameters to pass on the ode function

atol

absolute error tolerance for the numerical integration using deSolve.

rtol

relative error tolerance for the numerical integration using deSolve.

tcrit

the time you don't want to exceed in the integration

methode

specifies how the integration must be performed:

  • lsodes: use lsodes and deSolve::ode

  • ode45: use ode45 and deSolve::ode

  • lsoda: use lsoda and deSolve::ode

Author(s)

Rampal S. Etienne


Giappo/mbd documentation built on March 3, 2020, 3:36 a.m.