mbd_ode_fortran: Performs the integration of the ode using FORTRAN code

Description Usage Arguments Author(s)

View source: R/mbd_integrate.R

Description

Performs the integration of the ode using FORTRAN code

Usage

1
2
3
4
5
6
7
8
9
mbd_ode_fortran(
  initprobs,
  tvec,
  parsvec,
  atol,
  rtol,
  methode,
  runmod = "mbd_runmod"
)

Arguments

initprobs

initial probabilities

tvec

vector of times

parsvec

vector of parameters for the FORTRAN subroutine.

atol

absolute error tolerance for the numerical integration using deSolve.

rtol

relative error tolerance for the numerical integration using deSolve.

methode

specifies how the integration must be performed:

  • lsodes: use lsodes and deSolve::ode

  • ode45: use ode45 and deSolve::ode

  • lsoda: use lsoda and deSolve::ode

runmod

FORTRAN subroutine's option

Author(s)

Rampal S. Etienne


Giappo/mbd documentation built on March 3, 2020, 3:36 a.m.