Description Usage Arguments Value Author(s)
Check mbd pars
1 2 3 4 5 6 7 8 | check_pars(
pars,
safety_checks = TRUE,
lambda_limit = 10,
mu_limit = 10,
nu_limit = 100,
q_threshold = 0.001
)
|
pars |
vector of parameters:
|
safety_checks |
TRUE if you want the parameters to be limited to a realistic, but not infinite, parameter space |
lambda_limit |
Upper limit to lambda estimations. |
mu_limit |
Upper limit to mu estimations. |
nu_limit |
Upper limit to nu estimations. |
q_threshold |
adds a threshold for the evaluation of q. This is due
because you never want |
Returns "wrong" if they are wrong, or "right" otherwise.
Giovanni Laudanno
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.