View source: R/mbd_loglik_utils.R
Check the vectors of probability sums computed during likelihood integration
1 | check_sum_probs(sum_probs_1, sum_probs_2)
|
sum_probs_1 |
vector of probability sums, used during the integration of mbd_loglik |
sum_probs_2 |
vector of probability sums, used during the integration of mbd_loglik |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.