Description Usage Arguments Details Author(s)
View source: R/mbd_loglik_utils.R
Creates the A matrix but in a slower, more understandable way.
1 | create_a_slow(pars, k, lx, no_species_out_of_the_matrix = FALSE)
|
pars |
vector of parameters:
|
k |
the number of visible species in the phylogeny at a given time. |
lx |
it is the number of ODEs considered for the computation. |
no_species_out_of_the_matrix |
If true prevents interactions from states describing number of species greater than lx |
This is not to be called by the user.
Giovanni Laudanno
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.