Description Usage Arguments Author(s)
performs integration of the ode
1 | mbd_integrate(y, times, func, parms, atol, rtol, tcrit, methode = "lsoda")
|
y |
something |
times |
vector of times |
func |
a function |
parms |
some parameters to pass on the ode function |
atol |
absolute error tolerance for the numerical integration using deSolve. |
rtol |
relative error tolerance for the numerical integration using deSolve. |
tcrit |
the time you don't want to exceed in the integration |
methode |
specifies how the integration must be performed:
|
Rampal S. Etienne
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.