Description Usage Arguments Author(s)
View source: R/mbd_integrate.R
Performs the integration of the ode using FORTRAN code
1 2 3 4 5 6 7 8 9 | mbd_ode_fortran(
initprobs,
tvec,
parsvec,
atol,
rtol,
methode,
runmod = "mbd_runmod"
)
|
initprobs |
initial probabilities |
tvec |
vector of times |
parsvec |
vector of parameters for the FORTRAN subroutine. |
atol |
absolute error tolerance for the numerical integration using deSolve. |
rtol |
relative error tolerance for the numerical integration using deSolve. |
methode |
specifies how the integration must be performed:
|
runmod |
FORTRAN subroutine's option |
Rampal S. Etienne
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.